Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/pi-hole/pi-hole.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAdam Warner <me@adamwarner.co.uk>2022-08-01 20:38:15 +0300
committerAdam Warner <me@adamwarner.co.uk>2022-08-01 20:38:15 +0300
commit6c7a28a7b562bb8b3772e751efbac8861e7b43c5 (patch)
tree2fb5e0e5fda7218eab3151ab40b652fb6419cf72
parentaa0a9e297655dac699753ff0ef81b195c2f4c400 (diff)
Dont use bash keywords/programs as variable names
-rwxr-xr-xgravity.sh24
1 files changed, 12 insertions, 12 deletions
diff --git a/gravity.sh b/gravity.sh
index 910940af..a35ff8d7 100755
--- a/gravity.sh
+++ b/gravity.sh
@@ -139,9 +139,9 @@ update_gravity_timestamp() {
# Import domains from file and store them in the specified database table
database_table_from_file() {
# Define locals
- local table source backup_path backup_file tmpFile type
+ local table src backup_path backup_file tmpFile list_type
table="${1}"
- source="${2}"
+ src="${2}"
backup_path="${piholeDir}/migration_backup"
backup_file="${backup_path}/$(basename "${2}")"
tmpFile="$(mktemp -p "/tmp" --suffix=".gravity")"
@@ -155,13 +155,13 @@ database_table_from_file() {
# Special handling for domains to be imported into the common domainlist table
if [[ "${table}" == "whitelist" ]]; then
- type="0"
+ list_type="0"
table="domainlist"
elif [[ "${table}" == "blacklist" ]]; then
- type="1"
+ list_type="1"
table="domainlist"
elif [[ "${table}" == "regex" ]]; then
- type="3"
+ list_type="3"
table="domainlist"
fi
@@ -174,9 +174,9 @@ database_table_from_file() {
rowid+=1
fi
# Loop over all domains in ${source} file
# Read file line by line
- grep -v '^ *#' < "${source}" | while IFS= read -r domain
+ grep -v '^ *#' < "${src}" | while IFS= read -r domain
do
# Only add non-empty lines
if [[ -n "${domain}" ]]; then
@@ -185,10 +185,10 @@ database_table_from_file() {
echo "${rowid},\"${domain}\",${timestamp}" >> "${tmpFile}"
elif [[ "${table}" == "adlist" ]]; then
# Adlist table format
- echo "${rowid},\"${domain}\",1,${timestamp},${timestamp},\"Migrated from ${source}\",,0,0,0" >> "${tmpFile}"
+ echo "${rowid},\"${domain}\",1,${timestamp},${timestamp},\"Migrated from ${src}\",,0,0,0" >> "${tmpFile}"
else
# White-, black-, and regexlist table format
- echo "${rowid},${type},\"${domain}\",1,${timestamp},${timestamp},\"Migrated from ${source}\"" >> "${tmpFile}"
+ echo "${rowid},${list_type},\"${domain}\",1,${timestamp},${timestamp},\"Migrated from ${src}\"" >> "${tmpFile}"
fi
rowid+=1
fi
@@ -201,14 +201,14 @@ database_table_from_file() {
status="$?"
if [[ "${status}" -ne 0 ]]; then
- echo -e "\\n ${CROSS} Unable to fill table ${table}${type} in database ${gravityDBfile}\\n ${output}"
+ echo -e "\\n ${CROSS} Unable to fill table ${table}${list_type} in database ${gravityDBfile}\\n ${output}"
gravity_Cleanup "error"
fi
# Move source file to backup directory, create directory if not existing
mkdir -p "${backup_path}"
- mv "${source}" "${backup_file}" 2> /dev/null || \
- echo -e " ${CROSS} Unable to backup ${source} to ${backup_path}"
+ mv "${src}" "${backup_file}" 2> /dev/null || \
+ echo -e " ${CROSS} Unable to backup ${src} to ${backup_path}"
# Delete tmpFile
rm "${tmpFile}" > /dev/null 2>&1 || \
@@ -174,9 +174,9 @@ database_table_from_file() {
rowid+=1
fi
- # Loop over all domains in ${source} file
+ # Loop over all domains in ${src} file
# Read file line by line